@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -33,16 +29,17 @@ class dhcp_bootFixedAttributes(univention.admin.syntax.select):
 module = 'policies/dhcp_boot'
 operations = ['add', 'edit', 'remove', 'search']
 
-policy_oc = "univentionPolicyDhcpBoot"
-policy_apply_to = ["dhcp/host", "dhcp/pool", "dhcp/service", "dhcp/subnet", "dhcp/sharedsubnet", "dhcp/shared"]
-policy_position_dn_prefix = "cn=boot,cn=dhcp"
-policies_group = "dhcp"
+policy_oc = 'univentionPolicyDhcpBoot'
+policy_apply_to = ['dhcp/host', 'dhcp/pool', 'dhcp/service', 'dhcp/subnet', 'dhcp/sharedsubnet', 'dhcp/shared']
+policy_position_dn_prefix = 'cn=boot,cn=dhcp'
+policies_group = 'dhcp'
 childs = False
 short_description = _('Policy: DHCP Boot')
 object_name = _('DHCP Boot policy')
 object_name_plural = _('DHCP Boot policies')
 policy_short_description = _('Boot parameters')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -94,6 +91,7 @@ mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 mapping.register('boot_server', 'univentionDhcpBootServer', None, univention.admin.mapping.ListToString)
 mapping.register('boot_filename', 'univentionDhcpBootFilename', None, univention.admin.mapping.ListToString)
 register_policy_mapping(mapping)
+# fmt: on
 
 
 class object(univention.admin.handlers.simplePolicy):
