@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2011-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -32,7 +28,15 @@ module = 'policies/umc'
 operations = ('add', 'edit', 'remove', 'search')
 
 policy_oc = 'umcPolicy'
-policy_apply_to = ['users/user', 'users/ldap', 'groups/group', 'computers/domaincontroller_master', 'computers/domaincontroller_backup', 'computers/domaincontroller_slave', 'computers/memberserver']
+policy_apply_to = [
+    'users/user',
+    'users/ldap',
+    'groups/group',
+    'computers/domaincontroller_master',
+    'computers/domaincontroller_backup',
+    'computers/domaincontroller_slave',
+    'computers/memberserver',
+]
 policy_position_dn_prefix = 'cn=UMC'
 
 childs = False
@@ -42,6 +46,7 @@ object_name_plural = _('UMC policies')
 policy_short_description = _('Defines a set of allowed UMC operations')
 long_description = ''
 
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -87,6 +92,7 @@ mapping = udm_mapping.mapping()
 mapping.register('name', 'cn', None, udm_mapping.ListToString)
 mapping.register('allow', 'umcPolicyGrantedOperationSet')
 register_policy_mapping(mapping)
+# fmt: on
 
 
 class object(simplePolicy):
