@@ -490,7 +490,7 @@ def _doit(
     configRegistry.load()
 
     debug_level = int(configRegistry.get('directory/manager/cmd/debug/level', 0))
-    structured = configRegistry.is_true('directory/manager/cmd/debug/structured-logging', False)
+    structured = configRegistry.is_true('directory/manager/cmd/debug/structured-logging', True)
 
     if logfile:
         univention.logging.basicConfig(filename=logfile, univention_debug_level=debug_level, use_structured_logging=structured)
