@@ -9,16 +9,14 @@
 
 from ldap.filter import filter_format
 
-import univention.admin.handlers.users.user
 import univention.admin.modules
-import univention.admin.objects
 import univention.admin.uldap
 
 
 univention.admin.modules.update()
 
 
-def change(username, password):  # type: (str, str) -> None
+def change(username: str, password: str) -> None:
     """
     Change the password of the given user
 
